@@ -11,9 +11,12 @@ Strategy = SearchStrategy
 Coordinate = Real
 BoundingBox = Tuple[Coordinate, Coordinate, Coordinate, Coordinate]
 Point = Tuple[Coordinate, Coordinate]
+Multipoint = List[Point]
 Segment = Tuple[Point, Point]
 Multisegment = List[Segment]
 Contour = List[Point]
 Polyline = List[Point]
 Multicontour = List[Contour]
 Polygon = Tuple[Contour, Multicontour]
+Multipolygon = List[Polygon]
+Mix = Tuple[Multipoint, Multisegment, Multipolygon]
